Package: track2KBA
Title: Identifying Important Areas from Animal Tracking Data
Version: 1.1.3
Authors@R: c(
    person("Martin", "Beal", email = "martinbeal88@gmail.com", role = c("aut","cre"), comment = c(ORCID = "0000-0003-1654-1410")),
    person("Steffen", "Oppel", email = "steffen.oppel@gmail.com", role = "aut", comment = c(ORCID = "0000-0002-8220-3789")),
    person("Maria", "Dias", email = "maria.dias@birdlife.org", role = "aut", comment = c(ORCID = "0000-0002-7281-4391")),
    person("Mark", "Miller", email = "mark.gr.miller@gmail.com", role = "ctb"),
    person("Phillip", "Taylor",email = "philiprhodritaylor@googlemail.com", role = "ctb"),
    person("Virginia", "Morera-Pujol", email = "morera.virginia@gmail.com ", role = "ctb", comment = c(ORCID = "0000-0001-6500-5548")),
    person("Elizabeth", "Pearmain", email = "lizzie.pearmain@birdlife.org", role = "ctb", comment = c(ORCID = "0000-0002-6600-1482")),
    person("Jonathan", "Handley", email = "Jonathan.Handley@birdlife.org", role = "ctb", comment = c(ORCID = "0000-0001-6468-338X")),
    person("Ben", "Lascelles", email = "benlasc@gmail.com", role = "ctb"))
URL: https://github.com/BirdLifeInternational/track2kba
Description: Functions for preparing and analyzing animal tracking data, 
    with the intention of identifying areas which are potentially important at 
    the population level and therefore of conservation interest. Areas identified 
    using this package may be checked against global or regionally-defined criteria,
    such as those set by the Key Biodiversity Area program. The method
    published herein is described in full in Beal et al. 2021 <doi:10.1111/2041-210X.13713>.
Depends: R (>= 2.10)
License: LGPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
BugReports: https://github.com/BirdLifeInternational/track2kba/issues
Suggests: adehabitatLT, doParallel, knitr, parallel, rmarkdown,
        tinytest
VignetteBuilder: knitr
Imports: adehabitatHR, dplyr, foreach, geosphere, ggplot2, lubridate,
        magrittr, maps, Matching, methods, move, purrr, raster (>=
        3.6-3), rlang, sf (>= 0.7-4), sp (>= 1.5-0), tidyr
NeedsCompilation: no
Packaged: 2025-07-02 16:10:32 UTC; marti
Author: Martin Beal [aut, cre] (ORCID: <https://orcid.org/0000-0003-1654-1410>),
  Steffen Oppel [aut] (ORCID: <https://orcid.org/0000-0002-8220-3789>),
  Maria Dias [aut] (ORCID: <https://orcid.org/0000-0002-7281-4391>),
  Mark Miller [ctb],
  Phillip Taylor [ctb],
  Virginia Morera-Pujol [ctb] (ORCID:
    <https://orcid.org/0000-0001-6500-5548>),
  Elizabeth Pearmain [ctb] (ORCID:
    <https://orcid.org/0000-0002-6600-1482>),
  Jonathan Handley [ctb] (ORCID: <https://orcid.org/0000-0001-6468-338X>),
  Ben Lascelles [ctb]
Maintainer: Martin Beal <martinbeal88@gmail.com>
Repository: CRAN
Date/Publication: 2025-07-02 16:30:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:29:32 UTC; unix
