# Generated by roxygen2: do not edit by hand

export(estSpaceUse)
export(findScale)
export(findSite)
export(formatFields)
export(indEffectTest)
export(mapKDE)
export(mapSite)
export(mapTrips)
export(move2KBA)
export(projectTracks)
export(repAssess)
export(tripSplit)
export(tripSummary)
import(sp)
importFrom(Matching,ks.boot)
importFrom(adehabitatHR,estUDm2spixdf)
importFrom(adehabitatHR,getverticeshr)
importFrom(adehabitatHR,kernelUD)
importFrom(dplyr,arrange)
importFrom(dplyr,desc)
importFrom(dplyr,filter)
importFrom(dplyr,first)
importFrom(dplyr,group_by)
importFrom(dplyr,if_else)
importFrom(dplyr,lag)
importFrom(dplyr,last)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n_distinct)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,ungroup)
importFrom(foreach,"%dopar%")
importFrom(geosphere,centroid)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,borders)
importFrom(ggplot2,coord_sf)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_path)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_sf)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_colour_continuous)
importFrom(ggplot2,scale_fill_continuous)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,vars)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(graphics,abline)
importFrom(graphics,identify)
importFrom(graphics,image)
importFrom(graphics,lines)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,text)
importFrom(magrittr,"%>%")
importFrom(maps,map)
importFrom(methods,as)
importFrom(move,getMovebank)
importFrom(move,getMovebankData)
importFrom(move,getMovebankID)
importFrom(move,movebankLogin)
importFrom(rlang,.data)
importFrom(sf,st_as_sf)
importFrom(sf,st_bbox)
importFrom(sf,st_transform)
importFrom(sf,st_union)
importFrom(sp,CRS)
importFrom(sp,SpatialPixels)
importFrom(sp,SpatialPoints)
importFrom(sp,SpatialPointsDataFrame)
importFrom(sp,coordinates)
importFrom(sp,proj4string)
importFrom(sp,spDistsN1)
importFrom(sp,spTransform)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
